pub struct GeneratedIcydbConfig { /* private fields */ }Expand description
Validated IcyDB project config ready for build-script consumption.
Implementations
Sourceimpl GeneratedIcydbConfig
impl GeneratedIcydbConfig
Sourcepub const fn canisters(&self) -> &BTreeMap<String, GeneratedCanisterConfig>
pub const fn canisters(&self) -> &BTreeMap<String, GeneratedCanisterConfig>
Borrow validated per-canister config entries.
Sourcepub const fn build_target(&self) -> GeneratedBuildTarget
pub const fn build_target(&self) -> GeneratedBuildTarget
Return the build target used to resolve target-sensitive generated settings.
Sourcepub fn canister_sql_readonly_enabled(&self, canister_name: &str) -> bool
pub fn canister_sql_readonly_enabled(&self, canister_name: &str) -> bool
Return whether read-only SQL should be generated for one canister.
Sourcepub fn canister_sql_ddl_enabled(&self, canister_name: &str) -> bool
pub fn canister_sql_ddl_enabled(&self, canister_name: &str) -> bool
Return whether the SQL DDL endpoint should be generated for one canister.
Sourcepub fn canister_sql_fixtures_enabled(&self, canister_name: &str) -> bool
pub fn canister_sql_fixtures_enabled(&self, canister_name: &str) -> bool
Return whether SQL fixture lifecycle endpoints should be generated for one canister.
Sourcepub fn canister_sql_introspection_enabled(&self, canister_name: &str) -> bool
pub fn canister_sql_introspection_enabled(&self, canister_name: &str) -> bool
Return whether generated read-only SQL should admit operational introspection.
Sourcepub fn canister_sql_introspection_policy(
&self,
canister_name: &str,
) -> GeneratedSqlIntrospectionPolicy
pub fn canister_sql_introspection_policy( &self, canister_name: &str, ) -> GeneratedSqlIntrospectionPolicy
Return the local/IC introspection policy for one canister.
Sourcepub fn canister_sql_update_policy(
&self,
canister_name: &str,
) -> Option<GeneratedSqlUpdatePolicy>
pub fn canister_sql_update_policy( &self, canister_name: &str, ) -> Option<GeneratedSqlUpdatePolicy>
Return the configured generated SQL update endpoint policy, if any.
Sourcepub fn canister_metrics_enabled(&self, canister_name: &str) -> bool
pub fn canister_metrics_enabled(&self, canister_name: &str) -> bool
Return whether metrics report endpoints should be generated for one canister.
Sourcepub fn canister_metrics_extended_enabled(&self, canister_name: &str) -> bool
pub fn canister_metrics_extended_enabled(&self, canister_name: &str) -> bool
Return whether extended metrics report endpoints should be generated for one canister.
Sourcepub fn canister_snapshot_enabled(&self, canister_name: &str) -> bool
pub fn canister_snapshot_enabled(&self, canister_name: &str) -> bool
Return whether storage snapshot endpoints should be generated for one canister.
Sourcepub fn canister_schema_enabled(&self, canister_name: &str) -> bool
pub fn canister_schema_enabled(&self, canister_name: &str) -> bool
Return whether schema report endpoints should be generated for one canister.