pub struct ResolvedIcydbConfig { /* private fields */ }Expand description
Resolved IcyDB config and the path it came from, if a manifest exists.
Implementations
Sourceimpl ResolvedIcydbConfig
impl ResolvedIcydbConfig
Sourcepub fn config_path(&self) -> Option<&Path>
pub fn config_path(&self) -> Option<&Path>
Return the resolved config path, or None when no config file exists.
Sourcepub const fn config(&self) -> &GeneratedIcydbConfig
pub const fn config(&self) -> &GeneratedIcydbConfig
Borrow the validated generated config model.